@@ -29,9 +29,6 @@ def check_criterion_access(criterions):
 
 
 class AssetResource(Resource, ArgsMixin):
-    """
-    Retrieve or delete given asset.
-    """
 
     @jwt_required()
     def get(self, asset_id):
@@ -44,8 +41,8 @@ class AssetResource(Resource, ArgsMixin):
           - in: path
             name: asset_id
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
             required: True
         responses:
           200:
@@ -67,12 +64,12 @@ class AssetResource(Resource, ArgsMixin):
           - in: path
             name: asset_id
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
             required: True
         responses:
           204:
-            description: Given asset deleted
+            description: Empty response
         """
         force = self.get_force()
 
@@ -87,15 +84,11 @@ class AssetResource(Resource, ArgsMixin):
 
 
 class AllAssetsResource(Resource):
-    """
-    Retrieve all entities that are not shot or sequence.
-    Adds project name and asset type name.
-    """
 
     @jwt_required()
     def get(self):
         """
-        Retrieve all entities that are not shot or sequence.
+        Retrieve all entities that are not shot, sequence, episode, or edit.
         Adds project name and asset type name.
         ---
         tags:
@@ -121,18 +114,15 @@ class AllAssetsAliasResource(AllAssetsResource):
 
 
 class AssetsAndTasksResource(Resource, ArgsMixin):
-    """
-    Retrieve all entities that are not shot or sequence.
-    """
 
     @jwt_required()
     def get(self):
         """
-        Retrieve all entities that are not shot or sequence.
+        Retrieve all entities that are not shot, sequence, episode, or edit.
+        Adds project name and asset type name and all related tasks.
+        If episode_id is given as parameter, it returns assets not linked
+        to an episode and assets linked to given episode.
         ---
-        description: Adds project name and asset type name and all related tasks.
-                     If episode_id is given as parameter, it returns assets not linked
-                     to an episode and assets linked to given episode.
         tags:
           - Assets
         responses:
@@ -140,7 +130,6 @@ class AssetsAndTasksResource(Resource, ArgsMixin):
             description: All assets with tasks
         """
         criterions = query.get_query_criterions_from_request(request)
-        page = self.get_page()
         check_criterion_access(criterions)
         if permissions.has_vendor_permissions():
             criterions["assigned_to"] = persons_service.get_current_user()[
@@ -150,13 +139,10 @@ class AssetsAndTasksResource(Resource, ArgsMixin):
                 str(department.id)
                 for department in persons_service.get_current_user_raw().departments
             ]
-        return assets_service.get_assets_and_tasks(criterions, page)
+        return assets_service.get_assets_and_tasks(criterions)
 
 
 class AssetTypeResource(Resource):
-    """
-    Retrieve given asset type.
-    """
 
     @jwt_required()
     def get(self, asset_type_id):
@@ -169,8 +155,8 @@ class AssetTypeResource(Resource):
           - in: path
             name: asset_type_id
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
             required: True
         responses:
           200:
@@ -180,9 +166,6 @@ class AssetTypeResource(Resource):
 
 
 class AssetTypesResource(Resource):
-    """
-    Retrieve all asset types (entity types that are not shot, sequence or episode).
-    """
 
     @jwt_required()
     def get(self):
@@ -200,9 +183,6 @@ class AssetTypesResource(Resource):
 
 
 class ProjectAssetTypesResource(Resource):
-    """
-    Retrieve all asset types for given project.
-    """
 
     @jwt_required()
     def get(self, project_id):
@@ -215,8 +195,8 @@ class ProjectAssetTypesResource(Resource):
           - in: path
             name: project_id
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
             required: True
         responses:
           200:
@@ -227,14 +207,11 @@ class ProjectAssetTypesResource(Resource):
 
 
 class ShotAssetTypesResource(Resource):
-    """
-    Retrieve all asset shots for given shot.
-    """
 
     @jwt_required()
     def get(self, shot_id):
         """
-        Retrieve all asset shots for given shot.
+        Retrieve all asset types of assets casted in given shot.
         ---
         tags:
           - Assets
@@ -242,12 +219,12 @@ class ShotAssetTypesResource(Resource):
           - in: path
             name: shot_id
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
             required: True
         responses:
           200:
-            description: All asset shots for given shot
+            description: All asset types of assets casted in given shot
         """
         shot = shots_service.get_shot(shot_id)
         user_service.check_project_access(shot["project_id"])
@@ -255,9 +232,6 @@ class ShotAssetTypesResource(Resource):
 
 
 class ProjectAssetsResource(Resource):
-    """
-    Retrieve all assets for given project.
-    """
 
     @jwt_required()
     def get(self, project_id):
@@ -270,8 +244,8 @@ class ProjectAssetsResource(Resource):
           - in: path
             name: project_id
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
             required: True
         responses:
           200:
@@ -288,14 +262,11 @@ class ProjectAssetsResource(Resource):
 
 
 class ProjectAssetTypeAssetsResource(Resource):
-    """
-    Retrieve all assets for given project and entity type.
-    """
 
     @jwt_required()
     def get(self, project_id, asset_type_id):
         """
-        Retrieve all assets for given project and entity type.
+        Retrieve all assets for given project and asset type.
         ---
         tags:
             - Assets
@@ -304,17 +275,17 @@ class ProjectAssetTypeAssetsResource(Resource):
             name: project_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
           - in: path
             name: asset_type_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
         responses:
             200:
-                description: All assets for given project and entity type
+                description: All assets for given project and asset type
         """
         user_service.check_project_access(project_id)
         criterions = query.get_query_criterions_from_request(request)
@@ -328,14 +299,11 @@ class ProjectAssetTypeAssetsResource(Resource):
 
 
 class AssetAssetsResource(Resource):
-    """
-    Retrieve all assets for a given asset.
-    """
 
     @jwt_required()
     def get(self, asset_id):
         """
-        Retrieve all assets for a given asset.
+        Retrieve all assets linked to given asset.
         ---
         tags:
             - Assets
@@ -344,11 +312,11 @@ class AssetAssetsResource(Resource):
             name: asset_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
         responses:
             200:
-                description: All assets for a given asset
+                description: All assets linked to given asset
         """
         asset = assets_service.get_asset(asset_id)
         user_service.check_project_access(asset["project_id"])
@@ -356,11 +324,12 @@ class AssetAssetsResource(Resource):
         return breakdown_service.get_entity_casting(asset_id)
 
 
-class AssetTasksResource(Resource):
+class AssetTasksResource(Resource, ArgsMixin):
+
     @jwt_required()
     def get(self, asset_id):
         """
-        Retrieve all tasks related to a given shot.
+        Retrieve all tasks related to given asset.
         ---
         tags:
             - Assets
@@ -369,22 +338,25 @@ class AssetTasksResource(Resource):
             name: asset_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
         responses:
             200:
-                description: All tasks related to given shot
+                description: All tasks related to given asset
         """
         asset = assets_service.get_asset(asset_id)
         user_service.check_project_access(asset["project_id"])
-        return tasks_service.get_tasks_for_asset(asset_id)
+        return tasks_service.get_tasks_for_asset(
+            asset_id, relations=self.get_relations()
+        )
 
 
 class AssetTaskTypesResource(Resource):
+
     @jwt_required()
     def get(self, asset_id):
         """
-        Retrieve all task types related to a given asset.
+        Retrieve all task types of tasks related to given asset.
         ---
         tags:
             - Assets
@@ -393,11 +365,11 @@ class AssetTaskTypesResource(Resource):
             name: asset_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
         responses:
             200:
-                description: All task types related to given asset
+                description: All task types of tasks related to given asset
         """
         asset = assets_service.get_asset(asset_id)
         user_service.check_project_access(asset["project_id"])
@@ -405,14 +377,11 @@ class AssetTaskTypesResource(Resource):
 
 
 class NewAssetResource(Resource, ArgsMixin):
-    """
-    Create new asset resource.
-    """
 
     @jwt_required()
     def post(self, project_id, asset_type_id):
         """
-        Create new asset resource.
+        Create new asset with given parameters.
         ---
         tags:
             - Assets
@@ -421,18 +390,19 @@ class NewAssetResource(Resource, ArgsMixin):
             name: project_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
           - in: path
             name: asset_type_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
-          - in: body
-            name: Asset
-            description: Name, description, data and ID of asset
-            schema:
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
+        requestBody:
+          required: true
+          content:
+            application/json:
+              schema:
                 type: object
                 required:
                 - name
@@ -443,15 +413,19 @@ class NewAssetResource(Resource, ArgsMixin):
                 properties:
                     name:
                         type: string
+                        example: "Character Name"
                     description:
                         type: string
+                        example: "Main character"
                     data:
                         type: string
+                        example: "{}"
                     is_shared:
                         type: boolean
+                        example: false
                     source_id:
                         type: string
-                        format: UUID
+                        format: uuid
                         example: a24a6ea4-ce75-4665-a070-57453082c25
         responses:
             201:
@@ -484,7 +458,7 @@ class NewAssetResource(Resource, ArgsMixin):
                 ("data", {}, False, dict),
                 (
                     "is_shared",
-                    True,
+                    False,
                     False,
                     inputs.boolean,
                 ),
@@ -502,10 +476,11 @@ class NewAssetResource(Resource, ArgsMixin):
 
 
 class AssetCastingResource(Resource):
+
     @jwt_required()
     def get(self, asset_id):
         """
-        Resource to retrieve the casting of a given asset.
+        Retrieve the casting of a given asset.
         ---
         tags:
             - Assets
@@ -514,8 +489,8 @@ class AssetCastingResource(Resource):
             name: asset_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
         responses:
             200:
                 description: Casting of given asset
@@ -528,7 +503,7 @@ class AssetCastingResource(Resource):
     @jwt_required()
     def put(self, asset_id):
         """
-        Resource to allow the modification of assets linked to a asset.
+        Modify the casting of given asset.
         ---
         tags:
             - Assets
@@ -537,8 +512,15 @@ class AssetCastingResource(Resource):
             name: asset_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
+        requestBody:
+          required: true
+          content:
+            application/json:
+              schema:
+                type: object
+                description: Casting data to update
         responses:
             200:
                 description: Modification of assets linked to given asset
@@ -550,10 +532,11 @@ class AssetCastingResource(Resource):
 
 
 class AssetCastInResource(Resource):
+
     @jwt_required()
     def get(self, asset_id):
         """
-        Resource to retrieve the casting of a given asset.
+        Retrieve the list of shots that cast given asset.
         ---
         tags:
             - Assets
@@ -562,11 +545,11 @@ class AssetCastInResource(Resource):
             name: asset_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
         responses:
             200:
-                description: Casting of given asset
+                description: List of shots that cast given asset
         """
         asset = assets_service.get_asset(asset_id)
         user_service.check_project_access(asset["project_id"])
@@ -575,10 +558,11 @@ class AssetCastInResource(Resource):
 
 
 class AssetShotAssetInstancesResource(Resource):
+
     @jwt_required()
     def get(self, asset_id):
         """
-        Retrieve all shot asset instances linked to asset.
+        Retrieve all shot asset instances linked to given asset.
         ---
         tags:
             - Assets
@@ -587,11 +571,11 @@ class AssetShotAssetInstancesResource(Resource):
             name: asset_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
         responses:
             200:
-                description: All shot asset instances linked to asset
+                description: All shot asset instances linked to given asset
         """
         asset = assets_service.get_asset(asset_id)
         user_service.check_project_access(asset["project_id"])
@@ -602,7 +586,7 @@ class AssetSceneAssetInstancesResource(Resource):
     @jwt_required()
     def get(self, asset_id):
         """
-        Retrieve all scene asset instances linked to asset.
+        Retrieve all scene asset instances linked to given asset.
         ---
         tags:
             - Assets
@@ -611,11 +595,11 @@ class AssetSceneAssetInstancesResource(Resource):
             name: asset_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
         responses:
             200:
-                description: All scene asset instances linked to asset
+                description: All scene asset instances linked to given asset
         """
         asset = assets_service.get_asset(asset_id)
         user_service.check_project_access(asset["project_id"])
@@ -626,7 +610,7 @@ class AssetAssetInstancesResource(Resource, ArgsMixin):
     @jwt_required()
     def get(self, asset_id):
         """
-        Retrieve all asset instances instantiated inside this asset.
+        Retrieve all asset instances instantiated inside given asset.
         ---
         tags:
             - Assets
@@ -635,8 +619,8 @@ class AssetAssetInstancesResource(Resource, ArgsMixin):
             name: asset_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
         responses:
             200:
                 description: All asset instances instantiated inside given asset
@@ -657,8 +641,26 @@ class AssetAssetInstancesResource(Resource, ArgsMixin):
             name: asset_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
+        requestBody:
+          required: true
+          content:
+            application/json:
+              schema:
+                type: object
+                properties:
+                  asset_to_instantiate_id:
+                    type: string
+                    format: uuid
+                    required: true
+                    example: a24a6ea4-ce75-4665-a070-57453082c25
+                  description:
+                    type: string
+                    required: false
+                    example: "Asset instance description"
+                required:
+                  - asset_to_instantiate_id
         responses:
             201:
                 description: Asset instance created inside given asset
@@ -701,9 +703,6 @@ class BaseSetSharedAssetsResource(Resource, ArgsMixin):
 
 
 class SetSharedProjectAssetsResource(BaseSetSharedAssetsResource):
-    """
-    Share or unshare all assets (or a list of assets) for given project.
-    """
 
     @jwt_required()
     def post(self, project_id):
@@ -712,27 +711,31 @@ class SetSharedProjectAssetsResource(BaseSetSharedAssetsResource):
         ---
         tags:
         - Assets
-        consumes:
-            - multipart/form-data
         parameters:
           - in: path
             name: project_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
-          - in: formData
-            name: asset_ids
-            default: None,
-            type: array
-            items:
-                type: UUID
-            x-example: ["a24a6ea4-ce75-4665-a070-57453082c25"]
-          - in: formData
-            name: is_shared
-            default: true
-            type: boolean
-            x-example: true
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
+        requestBody:
+          required: false
+          content:
+            application/json:
+              schema:
+                type: object
+                properties:
+                  asset_ids:
+                    type: array
+                    items:
+                      type: string
+                      format: uuid
+                    default: null
+                    example: ["a24a6ea4-ce75-4665-a070-57453082c25"]
+                  is_shared:
+                    type: boolean
+                    default: true
+                    example: true
         responses:
             201:
                 description: All assets modified.
@@ -753,9 +756,6 @@ class SetSharedProjectAssetsResource(BaseSetSharedAssetsResource):
 
 
 class SetSharedProjectAssetTypeAssetsResource(BaseSetSharedAssetsResource):
-    """
-    Share or unshare all assets for given project and asset type.
-    """
 
     @jwt_required()
     def post(self, project_id, asset_type_id):
@@ -771,19 +771,25 @@ class SetSharedProjectAssetTypeAssetsResource(BaseSetSharedAssetsResource):
             name: project_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
           - in: path
             name: asset_type_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
-          - in: formData
-            name: is_shared
-            default: true
-            type: boolean
-            x-example: true
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
+        requestBody:
+          required: false
+          content:
+            application/json:
+              schema:
+                type: object
+                properties:
+                  is_shared:
+                    type: boolean
+                    default: true
+                    example: true
         responses:
             201:
                 description: All assets modified.
@@ -793,9 +799,6 @@ class SetSharedProjectAssetTypeAssetsResource(BaseSetSharedAssetsResource):
 
 
 class SetSharedAssetsResource(BaseSetSharedAssetsResource):
-    """
-    Share or unshare all assets (or a list of assets) for given project.
-    """
 
     @jwt_required()
     def post(self):
@@ -804,21 +807,24 @@ class SetSharedAssetsResource(BaseSetSharedAssetsResource):
         ---
         tags:
         - Assets
-        consumes:
-            - multipart/form-data
-        parameters:
-          - in: formData
-            name: asset_ids
-            default: None,
-            type: array
-            items:
-                type: UUID
-            x-example: ["a24a6ea4-ce75-4665-a070-57453082c25"]
-          - in: formData
-            name: is_shared
-            default: true
-            type: boolean
-            x-example: true
+        requestBody:
+          required: false
+          content:
+            application/json:
+              schema:
+                type: object
+                properties:
+                  asset_ids:
+                    type: array
+                    items:
+                      type: string
+                      format: uuid
+                    default: null
+                    example: ["a24a6ea4-ce75-4665-a070-57453082c25"]
+                  is_shared:
+                    type: boolean
+                    default: true
+                    example: true
         responses:
             201:
                 description: All assets modified.
@@ -856,8 +862,8 @@ class ProjectAssetsSharedUsedResource(Resource):
             name: project_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
         responses:
             200:
                 description: All shared assets used in project
@@ -867,6 +873,7 @@ class ProjectAssetsSharedUsedResource(Resource):
 
 
 class ProjectEpisodeAssetsSharedUsedResource(Resource):
+
     @jwt_required()
     def get(self, project_id, episode_id):
         """
@@ -879,14 +886,14 @@ class ProjectEpisodeAssetsSharedUsedResource(Resource):
             name: project_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
           - in: path
             name: episode_id
             required: True
             type: string
-            format: UUID
-            x-example: a24a6ea4-ce75-4665-a070-57453082c25
+            format: uuid
+            example: a24a6ea4-ce75-4665-a070-57453082c25
         responses:
             200:
                 description: All shared assets used in project episode
